@@ -5,7 +5,7 @@ For detailed documentation, please refer to the [documentation website](TODO).
 
 ## Bundling
 
-This package simply bundles various packages from the `@aws-prototyping-sdk` namespace which have been marked as stable. As such, not all constructs or projen packages may be exported from this package and as such may need to be explicitly imported by creating a dependency on the individual packages.
+This package simply bundles various packages from the `@aws-prototyping-sdk` namespace which have been marked as `stable`. As such, not all constructs or classes may be exported from this package and will need to be explicitly imported by creating a dependency on the individual packages.
 
 To illustrate, at the time of writing the following individual packages are published:
 
@@ -31,7 +31,7 @@ This means if you wanted to access the PDKPipeline which is a stable construct,
 import { nx_monorepo, pipeline } from "aws-prototyping-sdk";
 ```
 
-To import experimental constructs, a dependency on the individual package is required. In the case of `static-website` a dependency on `@aws-prototyping-sdk/static-website` is required. The constructs can then be imported as follows:
+To import `experimental` constructs, a dependency on the individual package is required. In the case of `static-website`, a dependency on `@aws-prototyping-sdk/static-website` is required. The constructs can then be imported as follows:
 
 ```python
 import { StaticWebsite } from "@aws-prototyping-sdk/static-website";
